"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TapeSession = void 0;
const zlib_1 = require("zlib");
class TapeSession {
    constructor(records) {
        this.records = records || [];
    }
    async readFromServer(contents) {
        // un-gzip and un-json the blob
        const uncompressed = (0, zlib_1.gunzipSync)(contents);
        const jsonPayload = JSON.parse(uncompressed.toString());
        // Un-base64 the bodies
        this.records = jsonPayload.map((record) => {
            return {
                ...record,
                request: {
                    ...record.request,
                    body: Buffer.from(record.request.body, 'base64'),
                },
                response: {
                    ...record.response,
                    body: Buffer.from(record.response.body, 'base64'),
                }
            };
        });
    }
    toServer() {
        // Base64 the bodies
        const jsonPayload = this.records.map((record) => {
            return {
                ...record,
                request: {
                    ...record.request,
                    body: record.request.body.toString('base64'),
                },
                response: {
                    ...record.response,
                    body: record.response.body.toString('base64'),
                }
            };
        });
        // Json and gzip the blob
        const compressed = (0, zlib_1.gzipSync)(JSON.stringify(jsonPayload));
        return compressed;
    }
}
exports.TapeSession = TapeSession;
//# sourceMappingURL=tape.js.map