"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchWithProxy = exports.streamToBuffer = exports.sleep = exports.fetchWithTimeout = void 0;
const node_fetch_1 = __importDefault(require("node-fetch"));
const https_proxy_agent_1 = require("https-proxy-agent");
const https_1 = require("https");
const fetchWithTimeout = async (url, options) => {
    const { timeout } = options;
    const controller = new AbortController();
    const id = setTimeout(() => controller.abort(), timeout);
    const response = await (0, node_fetch_1.default)(url, {
        ...options,
        //signal: controller.signal,
        // Non-standard timeout parameter specified in node-fetch
        // We use this instead of the signal because the 2.x.x signal type definitions
        // are incompatible. They were fixed in 3.x but 3.x also brought along ESM only requirements
        // that we don't currently use.
        timeout,
    });
    clearTimeout(id);
    return response;
};
exports.fetchWithTimeout = fetchWithTimeout;
const sleep = (ms) => {
    return new Promise(resolve => setTimeout(resolve, ms));
};
exports.sleep = sleep;
const streamToBuffer = (stream) => {
    // Right now we can't typehint the stream because node's built-in ReadableStream
    // typehint is missing `.on` properties
    return new Promise((resolve, reject) => {
        const _buf = [];
        stream.on("data", (chunk) => _buf.push(chunk));
        stream.on("end", () => resolve(Buffer.concat(_buf)));
        stream.on("error", (err) => reject(err));
    });
};
exports.streamToBuffer = streamToBuffer;
/**
 * @param {import('./index').Groove} proxy - proxy instance
 * @param {RequestOptions?} configuration - configuration for the request
 */
const fetchWithProxy = async (url, proxy, configuration) => {
    /*
     * Helper method to fetch through the proxy while respecting the locally signed certificates
     * For the configuration paramter pass anything that would normally be passed to `https.request`
     */
    const agent = new https_proxy_agent_1.HttpsProxyAgent(proxy.baseUrlProxy);
    return new Promise((resolve, reject) => {
        (0, https_1.request)(url, {
            agent,
            ca: proxy.certificate,
            ...(configuration || {}),
        }, (response) => {
            let data = "";
            response.on("data", (chunk) => {
                data = data + chunk.toString();
            });
            response.on("end", () => {
                resolve(data);
            });
            response.on("error", (error) => {
                reject(error);
            });
        }).end();
    });
};
exports.fetchWithProxy = fetchWithProxy;
//# sourceMappingURL=utilities.js.map